@@ -147,7 +147,6 @@ QString ReportInterface::generateReportFullText(DrKonqiStamp stamp, Backtrace in
 
     report.append(QStringLiteral("Operating System: %1\n").arg(sysInfo->operatingSystem()));
     report.append(QStringLiteral("Windowing System: %1\n").arg(sysInfo->windowSystem()));
-    report.append(QStringLiteral("Drkonqi Version: %1\n").arg(QString::fromLatin1(PROJECT_VERSION)));
 
     // LSB output or manually selected distro
     if (!sysInfo->distributionPrettyName().isEmpty()) {
@@ -155,6 +154,8 @@ QString ReportInterface::generateReportFullText(DrKonqiStamp stamp, Backtrace in
     } else if (!sysInfo->bugzillaPlatform().isEmpty() && sysInfo->bugzillaPlatform() != QLatin1String("unspecified")) {
         report.append(QStringLiteral("Distribution (Platform): %1\n").arg(sysInfo->bugzillaPlatform()));
     }
+
+    report.append(QStringLiteral("DrKonqi: %1 [%2]\n").arg(QString::fromLatin1(PROJECT_VERSION), DrKonqi::backendClassName()));
     report.append(QLatin1Char('\n'));
 
     // Details of the crash situation
@@ -269,7 +270,7 @@ QString ReportInterface::generateAttachmentComment() const
     QString comment;
 
     // Program name and versions
-    comment.append(QStringLiteral("%1 (%2) using Qt %4\n\n").arg(crashedApp->fakeExecutableBaseName()).arg(crashedApp->version()).arg(sysInfo->qtVersion()));
+    comment.append(QStringLiteral("%1 (%2) using Qt %4\n\n").arg(crashedApp->fakeExecutableBaseName(), crashedApp->version(), sysInfo->qtVersion()));
 
     // Details of the crash situation
     if (isBugAwarenessPageDataUseful()) {
@@ -473,3 +474,8 @@ ApplicationDetailsExamples *ReportInterface::appDetailsExamples() const
 {
     return m_appDetailsExamples;
 }
+
+ProductMapping *ReportInterface::productMapping() const
+{
+    return m_productMapping;
+}
